@@ -17,7 +17,7 @@ try:
     from http_parser.http import HttpStream, BadStatusLine
     from http_parser.reader import SocketReader
 except ImportError:
-    raise ImportError("""http-parser isn't installed.
+    raise ImportError("""http-parser isn't installed or out of data.
 
         pip install http-parser""")
 
@@ -27,7 +27,7 @@ from restkit.conn import Connection
 from restkit.errors import RequestError, RequestTimeout, RedirectLimit, \
 NoMoreData, ProxyError
 from restkit.session import get_session
-from restkit.util import parse_netloc, rewrite_location
+from restkit.util import parse_netloc, rewrite_location, to_bytestring
 from restkit.wrappers import Request, Response
 
 MAX_CLIENT_TIMEOUT=300
@@ -76,6 +76,8 @@ class Client(object):
             use_proxy=False,
             max_tries=3,
             wait_tries=0.3,
+            max_conn=150,
+            pool_size=10,
             backend="thread",
             **ssl_args):
         """
@@ -128,6 +130,8 @@ class Client(object):
 
         session_options = dict(
                 retry_delay=wait_tries,
+                max_size = pool_size,
+                max_conn = max_conn,
                 retry_max = max_tries,
                 timeout = timeout)
 
@@ -143,6 +147,8 @@ class Client(object):
 
         self.max_tries = max_tries
         self.wait_tries = wait_tries
+        self.max_conn = max_conn
+        self.pool_size = pool_size
         self.timeout = timeout
 
         self._nb_redirections = self.max_follow_redirect
@@ -224,9 +230,9 @@ class Client(object):
 
                 if p.status_code != 200:
                     raise ProxyError("Tunnel connection failed: %d %s" %
-                            (resp.status_int, body))
-
-                _ = p.body_string()
+                            (p.status_code(), p.body_string()))
+                # read body
+                p.body_string()
 
             else:
                 headers = []
@@ -335,9 +341,10 @@ class Client(object):
 
                     if isinstance(request.body, types.StringTypes):
                         if msg is not None:
-                            conn.send(msg + request.body, chunked)
+                            conn.send(msg + to_bytestring(request.body),
+                                    chunked)
                         else:
-                            conn.send(request.body, chunked)
+                            conn.send(to_bytestring(request.body), chunked)
                     else:
                         if msg is not None:
                             conn.send(msg)
@@ -356,11 +363,11 @@ class Client(object):
                 return self.get_response(request, conn)
             except socket.gaierror, e:
                 if conn is not None:
-                    conn.close()
+                    conn.release(True)
                 raise RequestError(str(e))
             except socket.timeout, e:
                 if conn is not None:
-                    conn.close()
+                    conn.release(True)
                 raise RequestTimeout(str(e))
             except socket.error, e:
                 if log.isEnabledFor(logging.DEBUG):
@@ -377,7 +384,7 @@ class Client(object):
 
             except BadStatusLine:
                 if conn is not None:
-                    conn.close()
+                    conn.release(True)
 
                 # should raised an exception in other cases
                 request.maybe_rewind(msg="bad status line")
@@ -388,6 +395,9 @@ class Client(object):
                 # unkown error
                 log.debug("unhandled exception %s" %
                         traceback.format_exc())
+                if conn is not None:
+                    conn.release(True)
+
                 raise
             tries += 1
             self._pool.backend_mod.sleep(self.wait_tries)
