@@ -17,6 +17,7 @@ from restkit.errors import AlreadyRead, RequestError
 from restkit.forms import multipart_form_encode, form_encode
 from restkit.tee import ResponseTeeInput
 from restkit.util import to_bytestring
+from restkit.util import parse_cookie
 
 class Request(object):
 
@@ -215,13 +216,18 @@ class Response(object):
         self.final_url = request.url
         self.should_close = not resp.should_keep_alive()
 
+        # cookies
+        if 'set-cookie' in self.headers:
+            cookie_header = self.headers.get('set-cookie')
+            self.cookies = parse_cookie(cookie_header, self.final_url)
+
 
         self._closed = False
         self._already_read = False
 
         if request.method == "HEAD":
             """ no body on HEAD, release the connection now """
-            self.connection.release()
+            self.connection.release(True)
             self._body = StringIO("")
         else:
             self._body = resp.body_file()
@@ -242,6 +248,10 @@ class Response(object):
     def can_read(self):
         return not self._already_read
 
+
+    def close(self):
+        self.connection.release(True)
+
     def body_string(self, charset=None, unicode_errors="strict"):
         """ return body string, by default in bytestring """
 
@@ -252,7 +262,6 @@ class Response(object):
         body = self._body.read()
         self._already_read = True
 
-        # release connection
         self.connection.release(self.should_close)
 
         if charset is not None:
